import { useAjax } from '@/Hook/useAjax';
import { addPageCustomerGroupApi, getCustomerServiceGroupListApi } from '@/services/adqV3/global';
import { Form, Modal, Select } from 'antd';
import React, { useEffect, useState } from 'react';
import '../../tencentAdPutIn/index.less'
import SelectPage from './selectPage';

interface Props {
    adAccountId: number
    corpList?: { label: string, value: string }[]
    visible?: boolean
    onChange?: () => void
    onClose?: () => void
}

/**
 * 新增官方落地页与客服组关系
 * @param param0 
 * @returns 
 */
const AddPageTieUp: React.FC<Props> = ({ adAccountId, corpList, visible, onChange, onClose }) => {

    /*******************************************/
    const [form] = Form.useForm();
    const tencentCorpId = Form.useWatch('tencentCorpId', form)
    const [groupList, setGroupList] = useState<{ label: string, value: number }[]>([])

    const addPageCustomerGroup = useAjax((params) => addPageCustomerGroupApi(params))
    const getCustomerServiceGroupList = useAjax((params) => getCustomerServiceGroupListApi(params))
    // const getCorpListAll = useAjax(() => getCorpListAllApi())
    /*******************************************/

    /** 客服组 */
    useEffect(() => {
        if (adAccountId && tencentCorpId) {
            getCustomerServiceGroupList.run({ adAccountId, pageNum: 1, pageSize: 100, tencentCorpId }).then(res => {
                setGroupList(res?.records?.map((item: { groupName: string; groupId: number; }) => ({ label: item.groupName, value: item.groupId + '&&' + item.groupName })))
            }).catch(() => setGroupList([]))
        }
    }, [adAccountId, tencentCorpId])

    const handleOk = () => {
        form.validateFields().then(values => {
            const { customerGroup, page, ...params } = values
            const [customerGroupId, customerGroupName] = customerGroup.split('&&')
            const { pageId, pageName } = page
            addPageCustomerGroup.run({ adAccountId, customerGroupName, customerGroupId, pageId, pageName, ...params }).then((res) => {
                if (res)
                    onChange?.()
            })
        })
    };

    return <Modal
        title={<strong>新增官方落地页与客服组关系</strong>}
        open={visible}
        onOk={handleOk}
        onCancel={onClose}
        className='modalResetCss'
        confirmLoading={addPageCustomerGroup.loading}
    >
        <Form
            form={form}
            name='basicWechatTieUp'
            autoComplete="off"
            colon={false}
            labelCol={{ span: 5 }}
            labelAlign="left"
        >
            <Form.Item label={<strong>企微端企业</strong>} name="tencentCorpId" rules={[{ required: true, message: '请选择企业!' }]}>
                <Select
                    showSearch
                    placeholder="请选择企业"
                    filterOption={(input, option) =>
                        ((option?.label ?? '') as any).toLowerCase().includes(input.toLowerCase())
                    }
                    allowClear
                    options={corpList}
                />
            </Form.Item>
            {tencentCorpId && <Form.Item label={<strong>客服组</strong>} name="customerGroup" rules={[{ required: true, message: '请选择客服组!' }]}>
                <Select
                    showSearch
                    placeholder="请选择客服组"
                    filterOption={(input, option) =>
                        ((option?.label ?? '') as any).toLowerCase().includes(input.toLowerCase())
                    }
                    loading={getCustomerServiceGroupList.loading}
                    allowClear
                    options={groupList}
                />
            </Form.Item>}
            <Form.Item label={<strong>官方落地页</strong>} name="page" rules={[{ required: true, message: '请选择官方落地页!' }]}>
                <SelectPage accountId={adAccountId} />
            </Form.Item>
        </Form>
    </Modal>;
};

export default React.memo(AddPageTieUp);